;  (C) 2006 - Vincent Besanon <elguapito@free.fr>
; Quick & (not so) Dirty MSI package for ZABBIX 1.1.2 client for Windows

;--------------------------------
;Includes

  ; Modern UI
  !include "MUI.nsh"
  ; Text Functions
  !include "TextFunc.nsh"
  ; LogicLib
  !include "LogicLib.nsh"
  ; StrCase (see Include\StrCase.nsh for author info)
  !include ".\Include\StrCase.nsh"
  ;
  !include ".\include\GetParameters.nsh"
  !include ".\include\strstr.nsh"
  !include ".\include\GetParameterValue.nsh"
;--------------------------------
;General

  ;Name and file
  Name "Zabbix Agent"
  OutFile "zabbix_agent-1.1.2_installer.exe"

  ;Default installation folder
  InstallDir "$PROGRAMFILES\Zabbix Agent"
  
  ; Product Information
  VIAddVersionKey "ProductName" "Zabbix Agent"
  VIAddVersionKey "CompanyName" "ZABBIX"
  VIAddVersionKey "LegalCopyright" " ZABBIX SIA"
  VIAddVersionKey "FileDescription" "Zabbix Agent Installer"
  VIAddVersionKey "FileVersion" "1.1.2"

  VIProductVersion "1.1.2.0"

; Registry key to check for directory (so if you install again, it will 
  ; overwrite the old one automatically)
  InstallDirRegKey HKLM "Software\Zabbix Agent" "Install_Dir"
;--------------------------------
;Variables definitions

Var OUT
Var HOST
Var SERVER
Var RMTCMD
Var TMPHOST
Var RCMD
;--------------------------------
;Macros definitions
!macro PARAMETERNAME ParamName DefaultValue
  Push "${ParamName}" 
  Push "${DefaultValue}" 
  Call GetParameterValue
  Pop $${ParamName}
!macroend


!insertmacro ConfigWrite

;--------------------------------
;Interface Settings
  !define MUI_ICON ".\img\zabbix.ico"
  !define MUI_UNICON ".\img\zabbix.ico"
  !define MUI_HEADERIMAGE
  !define MUI_HEADERIMAGE_BITMAP ".\img\zabbix_logo.bmp"
  !define MUI_ABORTWARNING

;--------------------------------
;Pages

  !insertmacro MUI_PAGE_WELCOME
  !insertmacro MUI_PAGE_LICENSE ".\Installer\docs\LICENSE.txt"
  !insertmacro MUI_PAGE_COMPONENTS
  ; Custom page to set some options in config file
  Page custom ConfigOptions
  !insertmacro MUI_PAGE_DIRECTORY
  !insertmacro MUI_PAGE_INSTFILES
  
  !insertmacro MUI_UNPAGE_CONFIRM
  !insertmacro MUI_UNPAGE_INSTFILES

;--------------------------------
;Languages
 
  !insertmacro MUI_LANGUAGE "English"

;--------------------------------
;Reserve Files
  
  ;These files should be inserted before other files in the data block
  ;Keep these lines before any File command
  ;Only for solid compression (by default, solid compression is enabled for BZIP2 and LZMA)
  
  ReserveFile "ihm.ini"
  !insertmacro MUI_RESERVEFILE_INSTALLOPTIONS

;--------------------------------
;Installer Sections

Section "Zabbix Agent (required)" SEC01
  
  SectionIn RO
  
  ; Zabbix binaries & config file
  SetOutPath "$INSTDIR"
  File ".\Installer\ZabbixW32.exe"
  File ".\Installer\zabbix_agentd.conf"
  ; Zabbix docs & license
  File ".\Installer\docs\*"
  
  ; Read user input options
  
  !insertmacro MUI_INSTALLOPTIONS_READ $SERVER "ihm.ini" "Field 2" "State"
  !insertmacro MUI_INSTALLOPTIONS_READ $HOST   "ihm.ini" "Field 6" "State"
  !insertmacro MUI_INSTALLOPTIONS_READ $RMTCMD "ihm.ini" "Field 7" "State"
  
    
  ; Puts some info based on host in config file
  ${ConfigWrite} '$INSTDIR\zabbix_agentd.conf' 'Server=' '$SERVER' $OUT
  ${ConfigWrite} '$INSTDIR\zabbix_agentd.conf' 'Hostname=' '$HOST' $OUT
  ${ConfigWrite} '$INSTDIR\zabbix_agentd.conf' 'EnableRemoteCommands=' '$RMTCMD' $OUT

  DetailPrint "Registering Zabbix Agent in services..."
  nsExec::ExecToStack '"$INSTDIR\ZabbixW32.exe" --config "$INSTDIR\zabbix_agentd.conf" install'
  
  DetailPrint "Starting Zabbix Agent..."
  nsExec::ExecToStack '"$INSTDIR\ZabbixW32.exe" start'

  ; Write the installation path into the registry
  WriteRegStr HKLM "SOFTWARE\Zabbix Agent" "Install_Dir" "$INSTDIR"
  
  ; Write the uninstall keys for Windows
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\Zabbix Agent" "DisplayName" "Zabbix Agent"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\Zabbix Agent" "UninstallString" '"$INSTDIR\uninstall.exe"'
  WriteRegDWORD HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\Zabbix Agent" "NoModify" 1
  WriteRegDWORD HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\Zabbix Agent" "NoRepair" 1
  WriteUninstaller "uninstall.exe"
SectionEnd

Section "Zabbix Sender (optional)" SEC02
  SetOutPath "$INSTDIR"
  
  ; ADD FILES
  DetailPrint "Installing optional Zabbix Sender..."
  File ".\Installer\zabbix_sender.exe"
SectionEnd

;--------------------------------
; Descriptions

LangString DESC_SEC01 ${LANG_ENGLISH} "Install Zabbix Agent on a win32 platform"
LangString DESC_SEC02 ${LANG_ENGLISH} "Install Zabbix Sender to send custom value via command line"

!insertmacro MUI_FUNCTION_DESCRIPTION_BEGIN
  !insertmacro MUI_DESCRIPTION_TEXT ${SEC01} $(DESC_SEC01)
  !insertmacro MUI_DESCRIPTION_TEXT ${SEC02} $(DESC_SEC02)
!insertmacro MUI_FUNCTION_DESCRIPTION_END

;--------------------------------
;InstallerOptions (custom IHM) Functions

Function .onInit
  ;Extract InstallOptions INI files
  !insertmacro MUI_INSTALLOPTIONS_EXTRACT "ihm.ini"
  !insertmacro PARAMETERNAME SERVER NONE
  !insertmacro PARAMETERNAME RMTCMD 0
   StrCmp $RMTCMD 1 onInitEtap1 0
   strcpy $RMTCMD 0
   onInitEtap1:
   ReadEnvStr $TMPHOST COMPUTERNAME
   ${StrCase} $HOST $TMPHOST "L"
  !insertmacro MUI_INSTALLOPTIONS_WRITE "ihm.ini" "Field 2" "State" $SERVER
  !insertmacro MUI_INSTALLOPTIONS_WRITE "ihm.ini" "Field 6" "State" $HOST
  !insertmacro MUI_INSTALLOPTIONS_WRITE "ihm.ini" "Field 7" "State" $RMTCMD
FunctionEnd

LangString TEXT_IO_TITLE ${LANG_ENGLISH} "Configuration"
LangString TEXT_IO_SUBTITLE ${LANG_ENGLISH} "Set some options in the config file."

Function ConfigOptions
  ; Read value from %COMPUTERNAME% environment variable and store it in $HOST variable
  !insertmacro PARAMETERNAME SERVER NONE
  !insertmacro PARAMETERNAME RMTCMD 0
   StrCmp $RMTCMD 1 ConfigOptionsEtap1 0
   strcpy $RMTCMD 0
   ConfigOptionsEtap1:
   ReadEnvStr $TMPHOST COMPUTERNAME
   ${StrCase} $HOST $TMPHOST "L"
  !insertmacro MUI_HEADER_TEXT "$(TEXT_IO_TITLE)" "$(TEXT_IO_SUBTITLE)"
  ; Show default or detected value
  
  !insertmacro MUI_INSTALLOPTIONS_WRITE "ihm.ini" "Field 6" "State" $HOST
  !insertmacro MUI_INSTALLOPTIONS_WRITE "ihm.ini" "Field 2" "State" $SERVER 
  !insertmacro MUI_INSTALLOPTIONS_WRITE "ihm.ini" "Field 7" "State" $RMTCMD
  ; Show custom page
  !insertmacro MUI_INSTALLOPTIONS_DISPLAY "ihm.ini"
FunctionEnd

;--------------------------------
; Uninstaller

UninstallText "This will uninstall Zabbix Agent. Hit next to continue."

Section "Uninstall"
  
  ; Remove registry keys
  DeleteRegKey HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\Zabbix Agent"
  DeleteRegKey HKLM "SOFTWARE\Zabbix Agent"

  ; Stop and remove Zabbix Agent service
  DetailPrint "Stopping Zabbix Agent service..."
  nsExec::ExecToStack '"$INSTDIR\ZabbixW32.exe" stop'
  
  DetailPrint "Removing Zabbix Agent..."
  nsExec::ExecToStack '"$INSTDIR\ZabbixW32.exe" remove'

  ; Remove files and uninstaller
  Sleep 2000
  Delete "$INSTDIR\*"

  ; Remove install directory
  RMDir "$INSTDIR"

SectionEnd

